@@ -40,7 +40,7 @@
 //!
 //! # #[tokio::main] async fn main() -> Result<(), Box<dyn std::error::Error>> {
 //! let token = env::var("DISCORD_TOKEN")?;
-//! let (shard, mut events) = Shard::new(token, Intents::GUILD_MESSAGES);
+//! let (shard, mut events) = Shard::new(token, Intents::GUILD_MESSAGES).await?;
 //! shard.start().await?;
 //!
 //! // Create a cache, caching up to 10 messages per channel:
@@ -68,7 +68,7 @@
 //! [github link]: https://github.com/twilight-rs/twilight
 //! [license badge]: https://img.shields.io/badge/license-ISC-blue.svg?style=for-the-badge&logo=pastebin
 //! [license link]: https://github.com/twilight-rs/twilight/blob/main/LICENSE.md
-//! [rust badge]: https://img.shields.io/badge/rust-1.59+-93450a.svg?style=for-the-badge&logo=rust
+//! [rust badge]: https://img.shields.io/badge/rust-1.60+-93450a.svg?style=for-the-badge&logo=rust
 
 #![cfg_attr(docsrs, feature(doc_auto_cfg))]
 #![deny(
@@ -384,7 +384,7 @@ impl InMemoryCache {
     ///
     /// // later on...
     /// let guilds = cache.stats().guilds();
-    /// println!("guild count: {}", guilds);
+    /// println!("guild count: {guilds}");
     /// ```
     pub const fn stats(&self) -> InMemoryCacheStats<'_> {
         InMemoryCacheStats::new(self)
@@ -418,7 +418,7 @@ impl InMemoryCache {
     /// let user_id = Id::new(5);
     ///
     /// let permissions = cache.permissions().in_channel(user_id, channel_id)?;
-    /// println!("member has these permissions: {:?}", permissions);
+    /// println!("member has these permissions: {permissions:?}");
     /// # Ok(()) }
     /// ```
     #[cfg(feature = "permission-calculator")]
@@ -906,6 +906,7 @@ impl UpdateCache for Event {
             ChannelDelete(v) => c.update(v.deref()),
             ChannelPinsUpdate(v) => c.update(v),
             ChannelUpdate(v) => c.update(v.deref()),
+            CommandPermissionsUpdate(_) => {}
             GatewayHeartbeat(_) => {}
             GatewayHeartbeatAck => {}
             GatewayHello(_) => {}
@@ -917,6 +918,11 @@ impl UpdateCache for Event {
             GuildEmojisUpdate(v) => c.update(v),
             GuildStickersUpdate(v) => c.update(v),
             GuildIntegrationsUpdate(_) => {}
+            GuildScheduledEventCreate(_) => {}
+            GuildScheduledEventDelete(_) => {}
+            GuildScheduledEventUpdate(_) => {}
+            GuildScheduledEventUserAdd(_) => {}
+            GuildScheduledEventUserRemove(_) => {}
             GuildUpdate(v) => c.update(v.deref()),
             IntegrationCreate(v) => c.update(v.deref()),
             IntegrationDelete(v) => c.update(v.deref()),
@@ -973,10 +979,10 @@ impl UpdateCache for Event {
 mod tests {
     use crate::{test, InMemoryCache};
     use twilight_model::{
-        datetime::Timestamp,
         gateway::payload::incoming::RoleDelete,
         guild::{Member, Permissions, Role},
         id::Id,
+        util::Timestamp,
     };
 
     #[test]
