@@ -324,12 +324,7 @@ impl<'a> InMemoryCachePermissions<'a> {
     /// let user_id = Id::new(5);
     ///
     /// let permissions = cache.permissions().in_channel(user_id, channel_id)?;
-    /// println!(
-    ///     "User {} in channel {} has permissions {:?}",
-    ///     user_id,
-    ///     channel_id,
-    ///     permissions,
-    /// );
+    /// println!("User {user_id} in channel {channel_id} has permissions {permissions:?}");
     /// # Ok(()) }
     /// ```
     ///
@@ -411,12 +406,7 @@ impl<'a> InMemoryCachePermissions<'a> {
     /// let user_id = Id::new(5);
     ///
     /// let permissions = cache.permissions().root(user_id, guild_id)?;
-    /// println!(
-    ///     "User {} in guild {} has permissions {:?}",
-    ///     user_id,
-    ///     guild_id,
-    ///     permissions,
-    /// );
+    /// println!("User {user_id} in guild {guild_id} has permissions {permissions:?}");
     /// # Ok(()) }
     /// ```
     ///
@@ -566,7 +556,6 @@ mod tests {
             permission_overwrite::{PermissionOverwrite, PermissionOverwriteType},
             Channel, ChannelType,
         },
-        datetime::Timestamp,
         gateway::payload::incoming::{
             ChannelCreate, GuildCreate, MemberAdd, MemberUpdate, RoleCreate, ThreadCreate,
         },
@@ -578,6 +567,7 @@ mod tests {
             marker::{ChannelMarker, GuildMarker, RoleMarker, UserMarker},
             Id,
         },
+        util::Timestamp,
     };
 
     assert_fields!(ChannelErrorType::ChannelUnavailable: channel_id);
